@@ -1,32 +1,27 @@
 """Utilities for gen-sample commands."""
 import logging
 import shutil
-import sys
+from pathlib import Path
 
-import six
+import click
 from cfn_flip import to_yaml
 
 from ....blueprints.tf_state import TfState
-from ....cfngin.context import Context as CFNginContext
-
-if sys.version_info.major > 2:
-    from pathlib import Path  # pylint: disable=E
-else:
-    from pathlib2 import Path  # pylint: disable=E
+from ....context import CfnginContext
 
 LOGGER = logging.getLogger(__name__.replace("._", "."))
 ROOT = Path(__file__).parent.parent.parent.parent
 TEMPLATES = ROOT / "templates"
 
 
-def convert_gitignore(src):
+def convert_gitignore(src: Path) -> Path:
     """Rename a gitignore template.
 
     Keyword Args:
-        src (Path): Path object for source file.
+        Path object for source file.
 
     Returns:
-        Optional[Path]: The renamed file if it was created.
+        The renamed file if it was created.
 
     """
     gitignore = src.parent / ".gitignore"
@@ -35,36 +30,32 @@ def convert_gitignore(src):
     return gitignore
 
 
-def copy_sample(ctx, src, dest):
+def copy_sample(ctx: click.Context, src: Path, dest: Path) -> None:
     """Copy a sample directory.
 
     Args:
-        ctx (click.Context): Click context object.
-        src (Path): Source path.
-        dest (Path): Destination path.
+        ctx: Click context object.
+        src: Source path.
+        dest: Destination path.
 
     """
     if dest.exists():
         LOGGER.error("Directory %s already exists!", dest)
         ctx.exit(1)
     LOGGER.debug('copying "%s" to "%s"', src, dest)
-    shutil.copytree(str(src), str(dest))
+    shutil.copytree(src, dest)
 
 
-def write_tfstate_template(dest):
-    # type: (Path) -> None
+def write_tfstate_template(dest: Path) -> None:
     """Write TfState blueprint as a YAML CFN template.
 
     Args:
-        dest (Path): File to be written to.
+        dest: File to be written to.
 
     """
     LOGGER.debug('writing TfState as a YAML template to "%s"', dest)
-    # TODO remove use of six.u when dripping python 2 support
     dest.write_text(
-        six.u(
-            to_yaml(
-                TfState("test", CFNginContext({"namespace": "test"}), None).to_json()
-            )
+        to_yaml(
+            TfState("test", CfnginContext(environment={"namespace": "test"})).to_json()
         )
     )
