@@ -64,6 +64,12 @@ class StaticSite(Blueprint):
             "default": [],
             "description": "(Optional) Domain aliases the " "distribution",
         },
+        "Compress": {
+            "type": bool,
+            "default": True,
+            "description": "Whether the CloudFront default cache behavior will "
+            "automatically compress certain files.",
+        },
         "DisableCloudFront": {
             "type": bool,
             "default": False,
@@ -162,7 +168,7 @@ class StaticSite(Blueprint):
                 index_rewrite = self._get_index_rewrite_role_function_and_version()
                 lambda_function_associations = (
                     self.get_directory_index_lambda_association(
-                        lambda_function_associations, index_rewrite["version"]
+                        lambda_function_associations, index_rewrite.get("version", "")
                     )
                 )
 
@@ -245,7 +251,7 @@ class StaticSite(Blueprint):
             ],
             "DefaultCacheBehavior": cloudfront.DefaultCacheBehavior(
                 AllowedMethods=["GET", "HEAD"],
-                Compress=False,
+                Compress=self.variables.get("Compress", True),
                 DefaultTTL="86400",
                 ForwardedValues=cloudfront.ForwardedValues(
                     Cookies=cloudfront.Cookies(Forward="none"), QueryString=False
@@ -426,7 +432,7 @@ class StaticSite(Blueprint):
                 AccountId,
                 ":log-group:/aws/lambda/",
                 StackName,
-                "-%s-*" % function_name,
+                f"-{function_name}-*",
             ],
         )
 
@@ -439,7 +445,7 @@ class StaticSite(Blueprint):
                 AccountId,
                 ":log-group:/aws/lambda/*.",
                 StackName,
-                "-%s-*" % function_name,
+                f"-{function_name}-*",
             ],
         )
 
@@ -608,9 +614,11 @@ class StaticSite(Blueprint):
             )
         }
 
-        res["function"] = self.add_cloudfront_directory_index_rewrite(res["role"])
+        res["function"] = self.add_cloudfront_directory_index_rewrite(
+            res.get("role", "")
+        )
         res["version"] = self.add_cloudfront_directory_index_rewrite_version(
-            res["function"]
+            res.get("function", "")
         )
         return res
 
@@ -618,4 +626,6 @@ class StaticSite(Blueprint):
 # Helper section to enable easy blueprint -> template generation
 # (just run `python <thisfile>` to output the json)
 if __name__ == "__main__":
-    print(StaticSite("test", CfnginContext(parameters={"namespace": "test"})).to_json())
+    print(  # noqa: T001
+        StaticSite("test", CfnginContext(parameters={"namespace": "test"})).to_json()
+    )
