@@ -80,9 +80,11 @@ def _get_cert_arn_from_response(
         return cast("GetServerCertificateResponseTypeDef", result)["ServerCertificate"][
             "ServerCertificateMetadata"
         ]["Arn"]
-    return cast("UploadServerCertificateResponseTypeDef", result)[
-        "ServerCertificateMetadata"
-    ]["Arn"]
+    return (
+        cast("UploadServerCertificateResponseTypeDef", result)
+        .get("ServerCertificateMetadata", {})
+        .get("Arn", "")
+    )
 
 
 def _get_cert_contents(kwargs: Dict[str, Any]) -> Dict[str, Any]:
@@ -107,7 +109,7 @@ def _get_cert_contents(kwargs: Dict[str, Any]) -> Dict[str, Any]:
         if value is not None:
             continue
 
-        path = input("Path to %s (skip): " % (key,))
+        path = input(f"Path to {key} (skip): ")
         if path == "skip" or not path.strip():
             continue
 
@@ -162,7 +164,7 @@ def ensure_server_cert_exists(
     except ClientError:
         if prompt:
             upload = input(
-                "Certificate '%s' wasn't found. Upload it now? (yes/no) " % (cert_name,)
+                f"Certificate '{cert_name}' wasn't found. Upload it now? (yes/no) "
             )
             if upload != "yes":
                 return {}
