@@ -7,8 +7,10 @@ import os
 import sys
 from typing import TYPE_CHECKING, Any, Dict, List, Mapping, cast
 
+from pydantic import Extra, Field
+
 from ...exceptions import FailedVariableLookup
-from ...utils import load_object_from_string
+from ...utils import BaseModel, load_object_from_string
 from ...variables import Variable, resolve_variables
 from ..blueprints.base import Blueprint
 
@@ -27,6 +29,19 @@ class BlankBlueprint(Blueprint):
         """Create template without raising NotImplementedError."""
 
 
+class TagDataModel(BaseModel):
+    """AWS Resource Tag data model."""
+
+    key: str = Field(..., alias="Key")
+    value: str = Field(..., alias="Value")
+
+    class Config:
+        """Model configuration."""
+
+        allow_population_by_field_name = True
+        extra = Extra.forbid
+
+
 def full_path(path: str) -> str:
     """Return full path."""
     return os.path.abspath(os.path.expanduser(path))
@@ -60,7 +75,7 @@ def handle_hooks(  # pylint: disable=too-many-statements
         try:
             hook_paths.append(hook.path)
         except KeyError as exc:
-            raise ValueError("%s hook #%d missing path." % (stage, i)) from exc
+            raise ValueError(f"{stage} hook #{i} missing path.") from exc
 
     LOGGER.info("executing %s hooks: %s", stage, ", ".join(hook_paths))
     for hook in hooks:
