@@ -44,4 +44,4 @@ class EnvvarLookup(LookupHandler):
         try:
             return os.environ[value]
         except KeyError as exc:
-            raise ValueError('EnvVar "{}" does not exist'.format(value)) from exc
+            raise ValueError(f'EnvVar "{value}" does not exist') from exc
