@@ -163,7 +163,7 @@ class CfnginContext(BaseContext):
 
         return {
             "Bucket": self.bucket_name,
-            "Key": "persistent_graphs/{namespace}/{key}".format(
+            "Key": "persistent_graphs/{namespace}/{key}".format(  # noqa: FS002
                 namespace=self.config.namespace,
                 key=(
                     self.config.persistent_graph_key + ".json"
@@ -265,6 +265,7 @@ class CfnginContext(BaseContext):
                 self.s3_client,
                 self.bucket_name,
                 self.bucket_region,
+                create=False,
                 persist_graph=bool(self.persistent_graph_location),
             )
             self._s3_bucket_verified = True
@@ -439,7 +440,7 @@ class CfnginContext(BaseContext):
             ServerSideEncryption="AES256",
             ACL="bucket-owner-full-control",
             ContentType="application/json",
-            Tagging="{}={}".format(self._persistent_graph_lock_tag, lock_code),
+            Tagging=f"{self._persistent_graph_lock_tag}={lock_code}",
             **self.persistent_graph_location,
         )
         self.logger.debug(
@@ -511,13 +512,9 @@ class CfnginContext(BaseContext):
                 pass
             self._persistent_graph_lock_code = None
             self.logger.info(
-                'unlocked persistent graph "%s"',
-                "/".join(
-                    [
-                        self.persistent_graph_location["Bucket"],
-                        self.persistent_graph_location["Key"],
-                    ]
-                ),
+                'unlocked persistent graph "%s/%s"',
+                self.persistent_graph_location.get("Bucket"),
+                self.persistent_graph_location.get("Key"),
             )
             return True
         raise PersistentGraphCannotUnlock(
