@@ -2,7 +2,6 @@
 from . import s3
 from ._account import AccountDetails
 from ._assume_role import AssumeRole
-from ._cli import cli
 from ._response import BaseResponse, ResponseError, ResponseMetadata
 
 __all__ = [
@@ -11,6 +10,5 @@ __all__ = [
     "BaseResponse",
     "ResponseError",
     "ResponseMetadata",
-    "cli",
     "s3",
 ]
